@@ -15,11 +15,11 @@ Data::Consumer - Repeatedly consume a data resource in a robust way
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =cut
 
-$VERSION= '0.12';
+$VERSION= '0.13';
 
 =head1 SYNOPSIS
 
@@ -612,7 +612,7 @@ Returns $consumer. Will die if not 'unprocessed' state is defined.
 
 sub leave {
     my $self= shift;
-    confess("Can't leave as 'unprocessed' is undefined!") if !$self->{unprocessed};
+    confess("Can't leave as 'unprocessed' is undefined!") if not defined $self->{unprocessed};
     $self->{defer_leave}++;
     return $self;
 }
